==> qttranslations-everywhere-src-5.12.3.tar.xz: qttranslations-everywhere-src-5.12.3/translations/qtwebengine_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AlertDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation>Диалог оповещения</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Требуется авторизация</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Войти</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Log In</source>
        <translation>Войти</translation>
    </message>
</context>
<context>
    <name>ConfirmDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation>Диалог оповещения</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>PromptDialog</name>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Prompt Dialog</source>
        <translation>Диалог запроса</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Перезагрузить без кэша</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation>Открыть ссылку в этом окне</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрыть страницу</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Жирный</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Наклонный</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Подчёркнутый</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>По &amp;левому краю</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>По &amp;середине</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>По &amp;правому краю</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation>Увеличить &amp;отступ</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation>Уменьшить о&amp;тступ</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation>&amp;Нумерованный список</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation>&amp;Маркированный список</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Перезагрузить без кэша</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрыть страницу</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation>Открыть ссылку в этом окне</translation>
    </message>
    <message>
        <source>Open link in new background tab</source>
        <translation>Открыть ссылку в новой фоновой вкладке</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Жирный</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Наклонный</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Подчёркнутый</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>По &amp;левому краю</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>По &amp;середине</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>По &amp;правому краю</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation>Увеличить &amp;отступ</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation>Уменьшить о&amp;тступ</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation>&amp;Нумерованный список</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation>&amp;Маркированный список</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page? Changes that you made may not be saved.</source>
        <translation>Покинуть страницу? Сделанные изменения могут быть утеряны.</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперёд</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Перезагрузить</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Выберите каталог для передачи</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Извещение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Подтверждение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Приглашение Javascript - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Закрыть страницу?</translation>
    </message>
    <message>
        <source>Changes that you made may not be saved.</source>
        <translation>Сделанные изменения могут быть утеряны.</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineDownloadItem</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineNewViewRequest</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineSettings</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Невозможно создать отдельный экземпляр NavigationHistory</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Невозможно создать отдельный экземпляр FullScreenRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of %1</source>
        <translation>Невозможно создать отдельный экземпляр %1</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineErrorPage</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineTestEvent</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineTestEvent</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Подключение к прокси «%1» с использованием:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Введите имя пользователя и пароль для «%1» в %2://%3</translation>
    </message>
</context>
</TS>

==> qttranslations-everywhere-src-5.14.1.tar.xz: qttranslations-everywhere-src-5.14.1/translations/qtwebengine_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AlertDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation>Диалог оповещения</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Требуется авторизация</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Войти</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Log In</source>
        <translation>Войти</translation>
    </message>
</context>
<context>
    <name>ConfirmDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation>Диалог оповещения</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>DownloadInterruptReason</name>
    <message>
        <source>Unknown reason or not interrupted</source>
        <translation>Неизвестная причина или не прерывалась</translation>
    </message>
    <message>
        <source>General file operation failure</source>
        <translation>Сбой работы с файлом</translation>
    </message>
    <message>
        <source>The file cannot be written locally, due to access restrictions</source>
        <translation>Не удалось записать файл из-за ограничений доступа</translation>
    </message>
    <message>
        <source>Insufficient space on the target drive</source>
        <translation>Недостаточно места на целевом диске</translation>
    </message>
    <message>
        <source>The directory or file name is too long</source>
        <translation>Имя каталога или файла слишком длинное</translation>
    </message>
    <message>
        <source>The file size exceeds the file system limitation</source>
        <translation>Размер файла выходит за ограничения файловой системы</translation>
    </message>
    <message>
        <source>The file is infected with a virus</source>
        <translation>Файл заражён вирусом</translation>
    </message>
    <message>
        <source>Temporary problem (for example file in use, or too many open files)</source>
        <translation>Временная проблема (например, файл используется или слишком много открытых файлов)</translation>
    </message>
    <message>
        <source>The file was blocked due to local policy</source>
        <translation>Файл заблокирован согласно локальной политике</translation>
    </message>
    <message>
        <source>Checking the safety of the download failed due to unexpected reasons</source>
        <translation>По неизвестной причине не удалось проверить безопасность файла</translation>
    </message>
    <message>
        <source>File seek past the end of a file (resuming previously interrupted download)</source>
        <translation>Смещение за конец файла (возобновление прерванной ранее загрузки)</translation>
    </message>
    <message>
        <source>The partial file did not match the expected hash</source>
        <translation>Часть файла не соответствует ожидаемому хэшу</translation>
    </message>
    <message>
        <source>General network failure</source>
        <translation>Сетевая ошибка</translation>
    </message>
    <message>
        <source>The network operation has timed out</source>
        <translation>Истекло время сетевой операции</translation>
    </message>
    <message>
        <source>The network connection has been terminated</source>
        <translation>Сетевое соединение было разорвано</translation>
    </message>
    <message>
        <source>The server has gone down</source>
        <translation>Невозможно установить соединение с сервером</translation>
    </message>
    <message>
        <source>The network request was invalid (for example, the URL or scheme is invalid)</source>
        <translation>Неверный сетевой запрос (например, неверный URL или схема)</translation>
    </message>
    <message>
        <source>General server failure</source>
        <translation>Сбой сервера</translation>
    </message>
    <message>
        <source>The server does not have the requested data</source>
        <translation>На сервере отсутствуют запрошенные данные</translation>
    </message>
    <message>
        <source>The server did not authorize access to the resource</source>
        <translation>Сервер отклонил доступ к ресурсу</translation>
    </message>
    <message>
        <source>A problem with the server certificate occurred</source>
        <translation>Возникла проблема с сертификатом сервера</translation>
    </message>
    <message>
        <source>Access forbidden by the server</source>
        <translation>Доступ запрещён сервером</translation>
    </message>
    <message>
        <source>Unexpected server response</source>
        <translation>Неожиданный ответ сервера</translation>
    </message>
    <message>
        <source>Download canceled by the user</source>
        <translation>Загрузка отменена пользователем</translation>
    </message>
</context>
<context>
    <name>PromptDialog</name>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Prompt Dialog</source>
        <translation>Диалог запроса</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Перезагрузить без кэша</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation>Открыть ссылку в этом окне</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрыть страницу</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Жирный</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Наклонный</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Подчёркнутый</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>По &amp;левому краю</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>По &amp;середине</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>По &amp;правому краю</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation>Увеличить &amp;отступ</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation>Уменьшить о&amp;тступ</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation>&amp;Нумерованный список</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation>&amp;Маркированный список</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Перезагрузить без кэша</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрыть страницу</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation>Открыть ссылку в этом окне</translation>
    </message>
    <message>
        <source>Open link in new background tab</source>
        <translation>Открыть ссылку в новой фоновой вкладке</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Жирный</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Наклонный</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Подчёркнутый</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>По &amp;левому краю</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>По &amp;середине</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>По &amp;правому краю</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation>Увеличить &amp;отступ</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation>Уменьшить о&amp;тступ</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation>&amp;Нумерованный список</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation>&amp;Маркированный список</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page? Changes that you made may not be saved.</source>
        <translation>Покинуть страницу? Сделанные изменения могут быть утеряны.</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперёд</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Перезагрузить</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Выберите каталог для передачи</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Извещение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Подтверждение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Приглашение Javascript - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Покинуть страницу?</translation>
    </message>
    <message>
        <source>Changes that you made may not be saved.</source>
        <translation>Внесённые изменения могут быть утеряны.</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineDownloadItem</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineNewViewRequest</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Невозможно создать отдельный экземпляр NavigationHistory</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Невозможно создать отдельный экземпляр FullScreenRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of %1</source>
        <translation>Невозможно создать отдельный экземпляр %1</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineErrorPage</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineTestEvent</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineTestEvent</translation>
    </message>
</context>
<context>
    <name>RenderViewContextMenuQt</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Выделить всё</translation>
    </message>
    <message>
        <source>Paste and match style</source>
        <translation>Вставить с соответствием стилю</translation>
    </message>
    <message>
        <source>Open link in new window</source>
        <translation>Открыть ссылку в новом окне</translation>
    </message>
    <message>
        <source>Open link in new tab</source>
        <translation>Открыть ссылку в новой вкладке</translation>
    </message>
    <message>
        <source>Copy link address</source>
        <translation>Скопировать адрес ссылки</translation>
    </message>
    <message>
        <source>Save link</source>
        <translation>Сохранить ссылку</translation>
    </message>
    <message>
        <source>Copy image</source>
        <translation>Скопировать изображение</translation>
    </message>
    <message>
        <source>Copy image address</source>
        <translation>Скопировать адрес изображения</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Copy media address</source>
        <translation>Скопировать адрес ресурса</translation>
    </message>
    <message>
        <source>Show controls</source>
        <translation>Показать элементы управления</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Зациклить</translation>
    </message>
    <message>
        <source>Save media</source>
        <translation>Сохранить ресурс</translation>
    </message>
    <message>
        <source>Inspect</source>
        <translation>Исследовать</translation>
    </message>
    <message>
        <source>Exit full screen</source>
        <translation>Оконный режим</translation>
    </message>
    <message>
        <source>Save page</source>
        <translation>Сохранить страницу</translation>
    </message>
    <message>
        <source>View page source</source>
        <translation>Исходный код страницы</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Подключение к прокси «%1» с использованием:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Введите имя пользователя и пароль для «%1» в %2://%3</translation>
    </message>
</context>
<context>
    <name>WebContentsAdapter</name>
    <message>
        <source>HTTP-POST data can only be sent over HTTP(S) protocol</source>
        <translation>Данные HTTP-POST могут быть отправлены только через протокол HTTP(S)</translation>
    </message>
</context>
</TS>
